Volker Seizes Pittsburgh Pittsburgh, Pennsylvania March 27th 2004 10 players Patrick van der Reest Deck Name: Gratiano's Prima Donna Description: Lasombra S&B for the tournament in Pittsburgh, 3/27/04 Anyway, here's the decklist. There's not much new tech in here but for some concerted effort to keep blood on my vampires. I've found that the Hungry Coyote is close to miraculous for keeping alive if you feel you have to turtle up for a little while,and it's usually a turn well spent hunting with the HC around to recoup some blood spent on Dominate bleeds. Possible improvements: Drop one Kassiym from an extra copy of Banjoko, add an extra Path and reduce the number of Stone Travels for some extra combat defence. Maybe drop the prayer cards (Dramatic Upheaval, Graverobbing) and try to find some more Shroud of Absence... As it is, though, the deck performs well and cycles beautifully. True combat as a predator will likely crunch it, but true combat has to go upstream heavily or it won't survive, so you may be able to just sit it out for a while until the coast is clear. Crypt (12 cards, min=15, max=31, avg=5.83) ------------------------------------------ 3x Gratiano 8 DOM OBT obf pot priscus Lasombra:2 2x Julia Prima 7 DOM OBT aus myt Kiasyd:2 2x Kassiym Malikhair 6 MYT OBT dom for Kiasyd:2 1x Banjoko 5 DOM obt pot Lasombra:3 1x Guido Lucciano 5 OBT dom obf Lasombra:2 1x Ignacio, The Black Priest 4 dom obt pot Lasombra:2 1x Ramiro 4 dom obt vic Lasombra:2 1x Aaron Duggan, Cameron's Toady 2 obt Lasombra:2 Library (89 cards) Master (18) 1x Anarch Troublemaker 1x Barrens, The 4x Blood Doll 1x Capitalist 1x Chanjelin Ward 1x Dominate 1x Dreams of the Sphinx 1x Elysian Fields 1x Giant's Blood 1x Hungry Coyote, The 2x Path of Night, The 1x Political Hunting Ground 1x Power Structure 1x Secure Haven Action (15) 3x Dominate Kine 10x Govern the Unaligned 2x Graverobbing Political Action (1) 1x Dramatic Upheaval Action Modifier (31) 4x Command of the Beast 4x Conditioning 4x Foreshadowing Destruction 6x Shadow Play 1x Shroud of Absence 4x Shroud of Night 5x Stone Travel 3x Tenebrous Form Reaction (12) 6x Deflection 6x Wake with Evening's Freshness Combat (12) 2x Entombment 2x High Ground 3x Oubliette 5x Shadow Body